/*
    File: AboutBox.h
    
    Description:
        This file contains the routine prototypes for calls defined in AboutBox.c
	These routines are used to manage the about box window displayed when
	the user chooses 'About HTMLSample...' from the file menu.
	
	HTMLSample is an application illustrating how to use the new
	HTMLRenderingLib services found in Mac OS 9. HTMLRenderingLib
	is Apple's light-weight HTML rendering engine capable of
	displaying HTML files.

    Copyright:
         Copyright 1999 Apple Computer, Inc. All rights reserved.
    
    Disclaimer:
        IMPORTANT:  This Apple software is supplied to you by Apple Computer, Inc.
        ("Apple") in consideration of your agreement to the following terms, and your
        use, installation, modification or redistribution of this Apple software
        constitutes acceptance of these terms.  If you do not agree with these terms,
        please do not use, install, modify or redistribute this Apple software.

        In consideration of your agreement to abide by the following terms, and subject
        to these terms, Apple grants you a personal, non-exclusive license, under Apples
        copyrights in this original Apple software (the "Apple Software"), to use,
        reproduce, modify and redistribute the Apple Software, with or without
        modifications, in source and/or binary forms; provided that if you redistribute
        the Apple Software in its entirety and without modifications, you must retain
        this notice and the following text and disclaimers in all such redistributions of
        the Apple Software.  Neither the name, trademarks, service marks or logos of
        Apple Computer, Inc. may be used to endorse or promote products derived from the
        Apple Software without specific prior written permission from Apple.  Except as
        expressly stated in this notice, no other rights or licenses, express or implied,
        are granted by Apple herein, including but not limited to any patent rights that
        may be infringed by your derivative works or by other works in which the Apple
        Software may be incorporated.

        The Apple Software is provided by Apple on an "AS IS" basis.  APPLE MAKES NO
        WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED
        WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
        PURPOSE, REGARDING THE APPLE SOFTWARE OR ITS USE AND OPERATION ALONE OR IN
        COMBINATION WITH YOUR PRODUCTS.

        IN NO EVENT SHALL APPLE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR
        CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
        GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
        ARISING IN ANY WAY OUT OF THE USE, REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION
        OF THE APPLE SOFTWARE, HOWEVER CAUSED AND WHETHER UNDER THEORY OF CONTRACT, TORT
        (INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN IF APPLE HAS BEEN
        ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

    Change History (most recent first):
        Wed, Dec 22, 1999 -- created
*/



#ifndef __ABOUTBOX__
#define __ABOUTBOX__

#include <Types.h>
#include <Windows.h>


/* OpenAboutBox opens the about box window and returns
	a pointer to the window in *aboutBox.  There can only
	be one about box open at a time, so if the about box is
	already open, then this routine brings it to the front
	by calling SelectWindow before returning a pointer to
	it. */
OSStatus OpenAboutBox(WindowPtr *aboutBox);


/* EnsureAboutBoxIsClosed closes the about box window
	if it is open.  If it is not open then this routine does
	nothing. */
void EnsureAboutBoxIsClosed(void);


/* AboutBoxUpdate should be called for update events
	directed at the about box window.  It calls
	BeginUpdate and EndUpdate and does all of the
	drawing required to refresh the about box window. */
void AboutBoxUpdate(WindowPtr aboutBox);


/* AboutBoxActivate should be called for activate events
	directed at the about box window. */
void AboutBoxActivate(WindowPtr aboutBox, Boolean activate);


/* AboutBoxCloseWindow closes the about box window. 
	this routine deallocates any structures allocated
	by the OpenAboutBox. */
void AboutBoxCloseWindow(WindowPtr aboutBox);


/* IsAboutBox returns true if the window pointer
	in the aboutBox parameter is not NULL and
	points to the about box. */
Boolean IsAboutBox(WindowPtr aboutBox);


#endif

